@@ -138,6 +138,22 @@ class TextFormatter(BaseFormatter):
                 return k
         return None
 
+    def same_case(self, word, ending):
+        if word[-1] == word[-1].lower():
+            return ending.lower()
+
+        return ending.upper()
+
+    def plural_ending(self, word):
+        if self.lang == "en":
+            last_lower = word[-1].lower()
+            if last_lower == "s":
+                return word  # already plural
+            if last_lower == "y":
+                return word[:-1] + self.same_case(word, "ies")
+            return word + self.same_case(word, "s")
+        return word
+
     def format_text(self, text):
         """
         a whitelisted fashion as opposed to tokenizing
@@ -281,6 +297,9 @@ class TextFormatter(BaseFormatter):
             elif len(word) == 5 and word[:4].isdigit() and word[-1].lower() == "s":
                 # 1900s
                 to_append = self.n2w(word[:4], to="year")
+                to_append[-1] = self.plural_ending(
+                    to_append[-1]
+                )  # nineteen hundreds instead of nineteen hundred
             elif len(word) > 2 and word[:-2].isdigit() and word[-2:].lower() == "'s":
                 # 80's
                 to_append = self.n2w(word[:-2])
@@ -361,7 +380,7 @@ class PhoneFormatter(BaseFormatter):
             )
             return phone_root
 
-    def get_phone_stress(self, phone, sep="_"):
+    def get_phone_stress(self, phone, sep="_", return_detail=False):
         """
         0    — No stress
         1    — Primary stress
@@ -369,15 +388,16 @@ class PhoneFormatter(BaseFormatter):
 
         Return:
         None: no stress digit
-        True: stress must be performed
-        False: stress must not be performed
+        True/1 or 2: stress must be performed
+        False/0: stress must not be performed
         """
         if not phone or phone == sep:
             return None
         if self.lang == "en":
             phone_root = phone.split(sep)[0]
             if phone_root[-1].isdigit():
-                return int(phone_root[-1]) > 0
+                stress = int(phone_root[-1])
+                return stress if return_detail else stress > 0
 
         return None
 
